===============================
Gerbi's CMS documentation
===============================

Welcome on the documentation of the simple multilingual Gerbi CMS (package name: django-page-cms). You track the latest
changes to the code base on the `github project page <http://github.com/batiste/django-page-cms>`_.
To get more information about this CMS and its feature go to the :doc:`Introduction section </introduction>`.

For a quick install::

    $ pip install django-page-cms[full]; gerbi --create mywebsite

For more complete installations instructions go to 
the :doc:`Installation section </installation>`. To get source code with git use::

    $ git clone git://github.com/batiste/django-page-cms.git django-page-cms



Table of content
======================================

.. toctree::
    :maxdepth: 2

    introduction.rst
    contributions.rst
    placeholders.rst
    installation.rst
    display-content.rst
    navigation-template-tags.rst

    3rd-party-apps.rst
    commands.rst

    settings-list.rst
    changelog.rst
    page-api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

